@@ -101,7 +101,23 @@ class Image_Model:
 
         try:
             if response['status'] == 'Success':
-                print('Your model has been created!')
+                print('Your model has been created!\n\nDetails:')
+                print('-' * 20)
+                print(
+                    'Model Name: ' + model_name + '\n' +
+                    'Deployed: True\n' + 
+                    'Status: Complete'
+                )
+                
+                print('-' * 20)
+                print(
+                    'JSON:' +
+                    '\n{\n' +
+                    '   Model_name: ' + model_name + '\n'
+                    '   Deployed: True\n' + 
+                    '   Status: Complete\n}'
+                )
+
             else:
                 print(response)
         except:
@@ -171,7 +187,22 @@ class Image_Model:
             try:
                 if response['status'] == 'Success':
                     print('Prediction:', response['prediction'][0])
-                    print('Confidence Score:', str(round(response['prediction'][1], 2) * 100) + '%')
+    
+                    print('-' * 20)
+                    print(
+                        'Model Name: ' + model_name + '\n' +
+                        'Prediction: ' +  response['prediction'][0] + '\n' +
+                        'Status: Success'
+                    )
+                    
+                    print('-' * 20)
+                    print(
+                        'JSON:' +
+                        '\n{\n' +
+                        '   Model_name: ' + model_name + '\n'
+                        '   Prediction:' + response['prediction'][0] + '\n' +
+                        '   Status: Success\n}'
+                    )
                     return response['prediction'][0], round(response['prediction'][1], 2)
                 
                 else:
@@ -261,6 +292,21 @@ class Image_Model:
             try:
                 if response['status'] == 'Success':
                     print('Your Model has succesfully been updated!')
+                    print('-' * 20)
+                    print(
+                        'Model Name: ' + model_name + '\n' +
+                        'Deployed: True\n' + 
+                        'Status: Complete'
+                    )
+                    
+                    print('-' * 20)
+                    print(
+                        'JSON:' +
+                        '\n{\n' +
+                        '   Model_name: ' + model_name + '\n'
+                        '   Deployed: True\n' + 
+                        '   Status: Complete\n}'
+                    )
                 else:
                     print(response)
             except:
@@ -364,7 +410,23 @@ class Forecasting_Model:
 
             try:
                 if response['status'] == 'Success':
-                    print('Your model has successfully been created!')
+                    print('Your model has been created!\n\nDetails:')
+                    print('-' * 20)
+                    print(
+                        'Model Name: ' + model_name + '\n' +
+                        'Deployed: True\n' + 
+                        'Status: Complete'
+                    )
+                    
+                    print('-' * 20)
+                    print(
+                        'JSON:' +
+                        '\n{\n' +
+                        '   Model_name: ' + model_name + '\n'
+                        '   Deployed: True\n' + 
+                        '   Status: Complete\n}'
+                    )
+
                 else:
                     print(response)
             except:
@@ -424,7 +486,23 @@ class Forecasting_Model:
 
             try:
                 if response['status'] == 'Success':
-                    print('Predicted Value:', response['prediction'])
+                    print('Prediction:', response['prediction'])
+    
+                    print('-' * 20)
+                    print(
+                        'Model Name: ' + model_name + '\n' +
+                        'Prediction: ' +  response['prediction'][0] + '\n' +
+                        'Status: Success'
+                    )
+                    
+                    print('-' * 20)
+                    print(
+                        'JSON:' +
+                        '\n{\n' +
+                        '   Model_name: ' + model_name + '\n'
+                        '   Prediction:' + response['prediction'][0] + '\n' +
+                        '   Status: Success\n}'
+                    )
                     return response['prediction']
                 else:
                     print(response)
@@ -528,7 +606,22 @@ class Forecasting_Model:
 
             try:
                 if response['status'] == 'Success':
-                    print('Your model has successfully been created!')
+                    print('Your model has been updated!\n\nDetails:')
+                    print('-' * 20)
+                    print(
+                        'Model Name: ' + model_name + '\n' +
+                        'Deployed: True\n' + 
+                        'Status: Complete'
+                    )
+                    
+                    print('-' * 20)
+                    print(
+                        'JSON:' +
+                        '\n{\n' +
+                        '   Model_name: ' + model_name + '\n'
+                        '   Deployed: True\n' + 
+                        '   Status: Complete\n}'
+                    )
                 else:
                     print(response)
             except:
@@ -604,7 +697,22 @@ class Text_Model:
 
             try:
                 if response['status'] == 'Success':
-                    print('Your model has successfully been created!')
+                    print('Your model has been created!\n\nDetails:')
+                    print('-' * 20)
+                    print(
+                        'Model Name: ' + model_name + '\n' +
+                        'Deployed: True\n' + 
+                        'Status: Complete'
+                    )
+                    
+                    print('-' * 20)
+                    print(
+                        'JSON:' +
+                        '\n{\n' +
+                        '   Model_name: ' + model_name + '\n'
+                        '   Deployed: True\n' + 
+                        '   Status: Complete\n}'
+                    )
                 else:
                     print(response)
             except:
@@ -660,6 +768,21 @@ class Text_Model:
         try:
             if response['status'] == 'Success':
                 print('Prediction:', response['prediction'])
+                print('-' * 20)
+                print(
+                    'Model Name: ' + model_name + '\n' +
+                    'Prediction: ' +  response['prediction'][0] + '\n' +
+                    'Status: Success'
+                )
+                
+                print('-' * 20)
+                print(
+                    'JSON:' +
+                    '\n{\n' +
+                    '   Model_name: ' + model_name + '\n'
+                    '   Prediction:' + response['prediction'][0] + '\n' +
+                    '   Status: Success\n}'
+                )
                 return response['prediction']
             else:
                 print(response)
@@ -736,7 +859,22 @@ class Text_Model:
 
             try:
                 if response['status'] == 'Success':
-                    print('Your model has successfully been edited!')
+                    print('Your model has been updated!\n\nDetails:')
+                    print('-' * 20)
+                    print(
+                        'Model Name: ' + model_name + '\n' +
+                        'Deployed: True\n' + 
+                        'Status: Complete'
+                    )
+                    
+                    print('-' * 20)
+                    print(
+                        'JSON:' +
+                        '\n{\n' +
+                        '   Model_name: ' + model_name + '\n'
+                        '   Deployed: True\n' + 
+                        '   Status: Complete\n}'
+                    )
                 
                 else:
                     print(response)
